// Copyright 2023 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

syntax = "proto3";

package google.cloud.aiplatform.v1;

import "google/api/field_behavior.proto";
import "google/api/resource.proto";

option csharp_namespace = "Google.Cloud.AIPlatform.V1";
option go_package = "cloud.google.com/go/aiplatform/apiv1/aiplatformpb;aiplatformpb";
option java_multiple_files = true;
option java_outer_classname = "ServiceNetworkingProto";
option java_package = "com.google.cloud.aiplatform.v1";
option php_namespace = "Google\\Cloud\\AIPlatform\\V1";
option ruby_package = "Google::Cloud::AIPlatform::V1";

// Represents configuration for private service connect.
message PrivateServiceConnectConfig {
  // Required. If true, expose the IndexEndpoint via private service connect.
  bool enable_private_service_connect = 1
      [(google.api.field_behavior) = REQUIRED];

  // A list of Projects from which the forwarding rule will target the service
  // attachment.
  repeated string project_allowlist = 2;
}

// PscAutomatedEndpoints defines the output of the forwarding rule
// automatically created by each PscAutomationConfig.
message PscAutomatedEndpoints {
  // Corresponding project_id in pscAutomationConfigs
  string project_id = 1;

  // Corresponding network in pscAutomationConfigs.
  string network = 2;

  // Ip Address created by the automated forwarding rule.
  string match_address = 3;
}
